;;-----------------------------------------------------------------------------
;;   File:      dscr.a51
;;   Contents:   This file contains descriptor data tables.  
;;
;;   Copyright (c) 1997 AnchorChips, Inc. All rights reserved
;;-----------------------------------------------------------------------------
   
DSCR_DEVICE       equ    1      ;; Descriptor type: Device
DSCR_CONFIG       equ    2      ;; Descriptor type: Configuration
DSCR_STRING       equ    3      ;; Descriptor type: String
DSCR_INTRFC       equ    4      ;; Descriptor type: Interface
DSCR_ENDPNT       equ    5      ;; Descriptor type: Endpoint
DSCR_DEVQUAL      equ    6      ;; Descriptor type: Device Qualifier

DSCR_DEVICE_LEN   equ   18
DSCR_CONFIG_LEN   equ    9
DSCR_INTRFC_LEN   equ    9
DSCR_ENDPNT_LEN   equ    7
DSCR_DEVQUAL_LEN  equ   10

ET_CONTROL        equ    0      ;; Endpoint type: Control
ET_ISO            equ    1      ;; Endpoint type: Isochronous
ET_BULK           equ    2      ;; Endpoint type: Bulk
ET_INT            equ    3      ;; Endpoint type: Interrupt

public      DeviceDscr, DeviceQualDscr, HighSpeedConfigDscr, FullSpeedConfigDscr, StringDscr, UserDscr

;; TGE  DSCR   SEGMENT   CODE

;;-----------------------------------------------------------------------------
;; Global Variables
;;-----------------------------------------------------------------------------

;; TGE      rseg DSCR                 ;; locate the descriptor table in on-part memory.

      cseg at 90H               ;; TODO: this needs to be changed before release
DeviceDscr:   
      db   DSCR_DEVICE_LEN      ;; Descriptor length => 18 bytes
      db   DSCR_DEVICE          ;; Decriptor type => this is device descriptor = 01h
      dw   0002H                ;; Specification Version (BCD)
      db   0FFH                 ;; Device class => vendor specific
      db   0FFH                 ;; Device sub-class => vendor specific
      db   0FFH                 ;; Device protocol => vendor specific  
      db   64                   ;; Maximum packet size of EP0 =>  
      dw   04B4H      		;; Vendor ID => Cypress Semi
      dw   0210H      		;; Product ID (Sample Device) => ES USB FX2LP
      dw   0100H                ;; Product version ID / Device Release Number
      db   StringDscr1          ;; Manufacturer string index
      db   StringDscr2          ;; Product string index
      db   0                    ;; Serial number string index
      db   1                    ;; Number of configurations

DeviceQualDscr:
      db   DSCR_DEVQUAL_LEN     ;; Descriptor length
      db   DSCR_DEVQUAL         ;; Decriptor type
      dw   0002H                ;; Specification Version (BCD)
      db   0FFH                  ;; Device class
      db   0FFH                  ;; Device sub-class
      db   0FFH                  ;; Device protocol
      db   64                   ;; Maximum packet size
      db   1                    ;; Number of configurations
      db   0                    ;; Reserved

HighSpeedConfigDscr:   
      db   DSCR_CONFIG_LEN      ;; Descriptor length
      db   DSCR_CONFIG          ;; Descriptor type
      db   (HighSpeedConfigDscrEnd-HighSpeedConfigDscr) mod 256 ;; Total Length (LSB)                   ?
      db   (HighSpeedConfigDscrEnd-HighSpeedConfigDscr)  /  256 ;; Total Length (MSB)                   ?
      db   1                    ;; Number of interfaces
      db   1                    ;; Configuration value , which one should be selected by set_config request
      db   0                    ;; Configuration string
      db   80H                  ;; Attributes: Bus powered (b7) , no wakeup
      db   7DH                  ;; 7DH = 125 * 2mA = 250mA (maximum requestable)

;; Interface Descriptor
      db   DSCR_INTRFC_LEN      ;; Descriptor length
      db   DSCR_INTRFC          ;; Descriptor type
      db   0                    ;; Zero-based index of this interface
      db   0                    ;; Alternate setting
      db   1                    ;; Number of end points        
      db   0FFH                 ;; Interface class
      db   0FFH                 ;; Interface sub class
      db   0FFH                 ;; Interface protocol
      db   0                    ;; Interface descriptor string index
  
;; Endpoint Descriptor 6
      db   DSCR_ENDPNT_LEN      ;; Descriptor length
      db   DSCR_ENDPNT          ;; Descriptor type
      db   86H                  ;; Endpoint number, and direction
      db   ET_BULK              ;; Endpoint type
      db   00H                  ;; Maximun packet size (LSB)
      db   04H                  ;; Max packect size (MSB)
      db   00H                  ;; Polling interval

HighSpeedConfigDscrEnd:

FullSpeedConfigDscr:   
      db   DSCR_CONFIG_LEN      ;; Descriptor length
      db   DSCR_CONFIG          ;; Descriptor type
      db   (FullSpeedConfigDscrEnd-FullSpeedConfigDscr) mod 256 ;; Total Length (LSB)
      db   (FullSpeedConfigDscrEnd-FullSpeedConfigDscr)  /  256 ;; Total Length (MSB)
      db   1                    ;; Number of interfaces
      db   1                    ;; Configuration number
      db   0                    ;; Configuration string
      db   80H                  ;; Attributes (b7 - buspwr, b6 - selfpwr, b5 - rwu)
      db   7DH                  ;; Power requirement (div 2 ma)

;; Interface Descriptor
      db   DSCR_INTRFC_LEN      ;; Descriptor length
      db   DSCR_INTRFC          ;; Descriptor type
      db   0                    ;; Zero-based index of this interface
      db   0                    ;; Alternate setting
      db   1                    ;; Number of end points   
      db   0ffH                 ;; Interface class
      db   0ffH                  ;; Interface sub class
      db   0ffH                  ;; Interface sub sub class
      db   0                    ;; Interface descriptor string index
 
;; Endpoint Descriptor 6
      db   DSCR_ENDPNT_LEN      ;; Descriptor length
      db   DSCR_ENDPNT         	;; Descriptor type
      db   86H               	;; Endpoint number, and direction
      db   ET_BULK            	;; Endpoint type
      db   40H               	;; Maximun packet size (LSB)
      db   00H               	;; Max packect size (MSB)
      db   00H               	;; Polling interval

FullSpeedConfigDscrEnd:   

StringDscr:

StringDscr0:   
      db   StringDscr0End-StringDscr0      ;; String descriptor length
      db   DSCR_STRING
      db   09H,04H
StringDscr0End:

StringDscr1:   
      db   StringDscr1End-StringDscr1      ;; String descriptor length
      db   DSCR_STRING
      db   'x',00
      db   'x',00
      db   'x',00
      db   '/',00
      db   'x',00
      db   'x',00
      db   'x',00
StringDscr1End:

StringDscr2:   
      db   StringDscr2End-StringDscr2      ;; Descriptor length
      db   DSCR_STRING
      db   'x',00
      db   'x',00
      db   'x',00
      db   '-',00
      db   'x',00
      db   'x',00
      db   'x',00
      db   'x',00
      db   'x',00
StringDscr2End:

UserDscr:      
      dw   0000H
      end
      
